# ariamath
Aria Math -- a tiny mathematics library.

Note: Aria Math is not related to aria- packages on PyPi. The name comes from my favorite C418 track called "Aria Math"

This library currently has:
- Vectors

Not really function-packed as of now, huh? Well, while I'm busy learning maths I'll eventually expand it with other stuff.
Next on the line: Number Theory
